==> haskell-snap-server-1.1.2.1-201-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-snap-server.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 snap-server
version:              1.1.2.1
visibility:           public
id:                   snap-server-1.1.2.1-6Og03OUMg9G2nQa1B2UYak
key:                  snap-server-1.1.2.1-6Og03OUMg9G2nQa1B2UYak
license:              BSD-3-Clause
maintainer:           snap@snapframework.com
author:               Snap Framework Authors  (see CONTRIBUTORS)
homepage:             http://snapframework.com/
synopsis:             A web server for the Snap Framework
description:
    Snap is a simple and fast web development framework and server written in
    Haskell. For more information or to download the latest version, you can
    visit the Snap project website at <http://snapframework.com/>.

    The Snap HTTP server is a high performance web server library written in
    Haskell. Together with the @snap-core@ library upon which it depends, it
    provides a clean and efficient Haskell programming interface to the HTTP
    protocol.

category:             Web, Snap, IO-Streams
abi:                  345517ad50bf409f600b3084c371abdd
exposed:              True
exposed-modules:
    Snap.Http.Server Snap.Http.Server.Config Snap.Http.Server.Types
    Snap.Internal.Http.Server.Config Snap.Internal.Http.Server.Types
    System.FastLogger

hidden-modules:
    Paths_snap_server Control.Concurrent.Extended
    Snap.Internal.Http.Server.Address Snap.Internal.Http.Server.Clock
    Snap.Internal.Http.Server.Common Snap.Internal.Http.Server.Date
    Snap.Internal.Http.Server.Parser Snap.Internal.Http.Server.Session
    Snap.Internal.Http.Server.Socket Snap.Internal.Http.Server.Thread
    Snap.Internal.Http.Server.TimeoutManager
    Snap.Internal.Http.Server.TLS System.SendFile System.SendFile.Linux

import-dirs:          /usr/lib/ghc-9.4.8/site-local/snap-server-1.1.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/snap-server-1.1.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/snap-server-1.1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-snap-server
hs-libraries:         HSsnap-server-1.1.2.1-6Og03OUMg9G2nQa1B2UYak
depends:
    attoparsec-0.14.4-HXvPhgAZIYuDm9YtcrLhPL base-4.17.2.1
    blaze-builder-0.4.2.3-1WUo1omsOYUH2PSkelI6MS bytestring-0.11.5.3
    case-insensitive-1.2.1.0-3jbMOlKTiDn4NCqaBZ47Ne
    clock-0.8.4-JtEZsee8EOiJwpYhDnb7sP containers-0.6.7
    filepath-1.4.2.2 io-streams-1.5.2.2-7tQYo3gUmYY7lapxhwgAN9
    io-streams-haproxy-1.0.1.0-LxPTXeMitat78rW1oQU8iq
    lifted-base-0.2.3.12-L2N6U9lxrMyAkZgo4dcBxa mtl-2.2.2
    network-3.1.4.0-24l6wfZeDaoIo68scGYLPE
    old-locale-1.0.0.7-KCPcWVOQKME2P4y4gxzvhh
    snap-core-1.0.5.1-BCC9f3MO0Q23qfRkgTcbX9 text-2.0.2 time-1.12.2
    transformers-0.5.6.2 unix-2.7.3
    unix-compat-0.7.3-FZLvposRpy5EPSL1bbufv9
    vector-0.13.1.0-Dc65CzydytHE52tdajtbOv

haddock-interfaces:   /usr/share/doc/haskell-snap-server/html/snap-server.haddock
haddock-html:         /usr/share/doc/haskell-snap-server/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-snap-server-1.1.2.1-209-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-snap-server.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 snap-server
version:              1.1.2.1
visibility:           public
id:                   snap-server-1.1.2.1-9zCzP7d2u4qfCjXI5fxmU
key:                  snap-server-1.1.2.1-9zCzP7d2u4qfCjXI5fxmU
license:              BSD-3-Clause
maintainer:           snap@snapframework.com
author:               Snap Framework Authors  (see CONTRIBUTORS)
homepage:             http://snapframework.com/
synopsis:             A web server for the Snap Framework
description:
    Snap is a simple and fast web development framework and server written in
    Haskell. For more information or to download the latest version, you can
    visit the Snap project website at <http://snapframework.com/>.

    The Snap HTTP server is a high performance web server library written in
    Haskell. Together with the @snap-core@ library upon which it depends, it
    provides a clean and efficient Haskell programming interface to the HTTP
    protocol.

category:             Web, Snap, IO-Streams
abi:                  1536f0bfa249c0c84ac2a3e42c118cad
exposed:              True
exposed-modules:
    Snap.Http.Server Snap.Http.Server.Config Snap.Http.Server.Types
    Snap.Internal.Http.Server.Config Snap.Internal.Http.Server.Types
    System.FastLogger

hidden-modules:
    Paths_snap_server Control.Concurrent.Extended
    Snap.Internal.Http.Server.Address Snap.Internal.Http.Server.Clock
    Snap.Internal.Http.Server.Common Snap.Internal.Http.Server.Date
    Snap.Internal.Http.Server.Parser Snap.Internal.Http.Server.Session
    Snap.Internal.Http.Server.Socket Snap.Internal.Http.Server.Thread
    Snap.Internal.Http.Server.TimeoutManager
    Snap.Internal.Http.Server.TLS System.SendFile System.SendFile.Linux

import-dirs:          /usr/lib/ghc-9.4.8/site-local/snap-server-1.1.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/snap-server-1.1.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/snap-server-1.1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-snap-server
hs-libraries:         HSsnap-server-1.1.2.1-9zCzP7d2u4qfCjXI5fxmU
depends:
    attoparsec-0.14.4-CiUWnNTnUzcEcRmqqSBimu base-4.17.2.1
    blaze-builder-0.4.2.3-1WUo1omsOYUH2PSkelI6MS bytestring-0.11.5.3
    case-insensitive-1.2.1.0-9695IAuXzI9BpRD3yNxY1D
    clock-0.8.4-6FgXeklnU5u2N2WSIoBD30 containers-0.6.7
    filepath-1.4.2.2 io-streams-1.5.2.2-FnszSGPwaoDA02r8W5A05X
    io-streams-haproxy-1.0.1.0-31BTFVIoNTFL15dvw4imY6
    lifted-base-0.2.3.12-Ctjz0GODTPIHt4tCOWutZj mtl-2.2.2
    network-3.1.4.0-29qUxJkoDip75hxElAm7gZ
    old-locale-1.0.0.7-KCPcWVOQKME2P4y4gxzvhh
    snap-core-1.0.5.1-FYXaL5n0Y4DKNwLUXUHM6t text-2.0.2 time-1.12.2
    transformers-0.5.6.2 unix-2.7.3
    unix-compat-0.7.3-GKrDUqCOM7qIZhM6rNxdwj
    vector-0.13.2.0-F0gUvA5SUIr11j4RVHYOTP

haddock-interfaces:   /usr/share/doc/haskell-snap-server/html/snap-server.haddock
haddock-html:         /usr/share/doc/haskell-snap-server/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
